==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-float-pane-action.js <==
import { __extends } from "tslib";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { IgrPaneDragAction } from "./igr-pane-drag-action";
import { FloatPaneAction } from "./FloatPaneAction";
import { ensureEnum } from "igniteui-react-core";
var IgrFloatPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrFloatPaneAction, _super);
    function IgrFloatPaneAction(props) {
        return _super.call(this, props) || this;
    }
    IgrFloatPaneAction.prototype.createImplementation = function () {
        return new FloatPaneAction();
    };
    Object.defineProperty(IgrFloatPaneAction.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFloatPaneAction.prototype, "actionType", {
        get: function () {
            return this.i.b;
        },
        set: function (v) {
            this.i.b = ensureEnum(PaneDragActionType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFloatPaneAction.prototype, "location", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFloatPaneAction.prototype, "width", {
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFloatPaneAction.prototype, "height", {
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgrFloatPaneAction.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.location && this.location.name && this.location.name == name) {
            return this.location;
        }
        return null;
    };
    IgrFloatPaneAction.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.location && this.location._styling) {
            this.location._styling(container, component, this);
        }
        this._inStyling = false;
    };
    return IgrFloatPaneAction;
}(IgrPaneDragAction));
export { IgrFloatPaneAction };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-float-pane-action.js <==
import { __extends } from "tslib";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { IgrDockManagerPoint } from "./igr-dock-manager-point";
import { IgrPaneDragAction } from "./igr-pane-drag-action";
import { FloatPaneAction } from "./FloatPaneAction";
import { ensureEnum } from "igniteui-react-core";
var IgrFloatPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrFloatPaneAction, _super);
    function IgrFloatPaneAction(props) {
        return _super.call(this, props) || this;
    }
    IgrFloatPaneAction.prototype.createImplementation = function () {
        return new FloatPaneAction();
    };
    Object.defineProperty(IgrFloatPaneAction.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFloatPaneAction.prototype, "type", {
        get: function () {
            return this.i.b;
        },
        set: function (v) {
            this.i.b = ensureEnum(PaneDragActionType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFloatPaneAction.prototype, "location", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrDockManagerPoint();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFloatPaneAction.prototype, "width", {
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrFloatPaneAction.prototype, "height", {
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgrFloatPaneAction.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.location && this.location.name && this.location.name == name) {
            return this.location;
        }
        return null;
    };
    IgrFloatPaneAction.prototype.setNativeElement = function (element) {
        this.i.setNativeElement(element);
    };
    return IgrFloatPaneAction;
}(IgrPaneDragAction));
export { IgrFloatPaneAction };
